# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['omnikinverter']

package_data = \
{'': ['*']}

install_requires = \
['aiohttp>=3.0.0', 'yarl>=1.6.0']

setup_kwargs = {
    'name': 'omnikinverter',
    'version': '0.2.2',
    'description': 'Asynchronous Python client for the Omnik Inverter',
    'long_description': '## Python - Omnik Inverter Client\n\n<!-- PROJECT SHIELDS -->\n[![GitHub Release][releases-shield]][releases]\n[![Python Versions][python-versions-shield]][pypi]\n![Project Stage][project-stage-shield]\n![Project Maintenance][maintenance-shield]\n[![License][license-shield]](LICENSE)\n\n[![GitHub Activity][commits-shield]][commits-url]\n[![Forks][forks-shield]][forks-url]\n[![Stargazers][stars-shield]][stars-url]\n[![Issues][issues-shield]][issues-url]\n[![Contributors][contributors-shield]][contributors-url]\n\n[![Code Quality][code-quality-shield]][code-quality]\n[![Maintainability][maintainability-shield]][maintainability-url]\n[![GitHub Last Commit][last-commit-shield]][commits-url]\n\nAsynchronous Python client for the Omnik Inverter.\n\n## About\n\nA python package with which you can read the data from your Omnik Inverter. Keep in mind that this repository uses webscraping, this is **not** a neat way of data processing but due to the lack of a local API this is the only option.\n\n**NOTE**: In mid-2021, manufacturer Omnik was declared bankrupt. You can find more information about what your alternatives are [here][energiewacht].\n\n## Supported models\n\n- Omnik2000TL2\n\n## Installation\n\n```bash\npip install omnikinverter\n```\n\n## Usage\n\n```python\nimport asyncio\n\nfrom omnikinverter import OmnikInverter\n\n\nasync def main():\n    """Show example on getting Omnik Inverter data."""\n    async with OmnikInverter(host="example_host") as client:\n        inverter = await client.inverter()\n        print(inverter)\n\n\nif __name__ == "__main__":\n    loop = asyncio.get_event_loop()\n    loop.run_until_complete(main())\n```\n\n# Data\n\nYou can read the following data with this package:\n\n- Serial Number\n- Inverter Model\n- Firmware Version\n- Current Power Production (W)\n- Day Energy Production (kWh)\n- Total Energy Production (kWh)\n\n## Setting up development environment\n\nThis Python project is fully managed using the [Poetry][poetry] dependency\nmanager. But also relies on the use of NodeJS for certain checks during\ndevelopment.\n\nYou need at least:\n\n- Python 3.8+\n- [Poetry][poetry-install]\n\nCreate a virtualenv and enter it:\n\n```bash\npython3 -m venv venv\nsource venv/bin/activate\n```\n\nTo install all packages, including all development requirements:\n\n```bash\npoetry install\npre-commit install\n```\n\nAs this repository uses the [pre-commit][pre-commit] framework, all changes\nare linted and tested with each commit. You can run all checks and tests\nmanually, using the following command:\n\n```bash\npoetry run pre-commit run --all-files\n```\n\nTo run just the Python tests:\n\n```bash\npoetry run pytest\n```\n\n## License\n\nMIT License\n\nCopyright (c) 2021 Klaas Schoute\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the "Software"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.\n\n<!-- MARKDOWN LINKS & IMAGES -->\n[code-quality-shield]: https://img.shields.io/lgtm/grade/python/g/klaasnicolaas/python-omnikinverter.svg?logo=lgtm&logoWidth=18\n[code-quality]: https://lgtm.com/projects/g/klaasnicolaas/python-omnikinverter/context:python\n[contributors-shield]: https://img.shields.io/github/contributors/klaasnicolaas/python-omnikinverter.svg\n[contributors-url]: https://github.com/klaasnicolaas/python-omnikinverter/graphs/contributors\n[commits-shield]: https://img.shields.io/github/commit-activity/y/klaasnicolaas/python-omnikinverter.svg\n[commits-url]: https://github.com/klaasnicolaas/python-omnikinverter/commits/master\n[forks-shield]: https://img.shields.io/github/forks/klaasnicolaas/python-omnikinverter.svg\n[forks-url]: https://github.com/klaasnicolaas/python-omnikinverter/network/members\n[issues-shield]: https://img.shields.io/github/issues/klaasnicolaas/python-omnikinverter.svg\n[issues-url]: https://github.com/klaasnicolaas/python-omnikinverter/issues\n[license-shield]: https://img.shields.io/github/license/klaasnicolaas/python-omnikinverter.svg\n[last-commit-shield]: https://img.shields.io/github/last-commit/klaasnicolaas/python-omnikinverter.svg\n[maintenance-shield]: https://img.shields.io/maintenance/yes/2021.svg\n[maintainability-shield]: https://api.codeclimate.com/v1/badges/443c476612a574d82467/maintainability\n[maintainability-url]: https://codeclimate.com/github/klaasnicolaas/python-omnikinverter/maintainability\n[project-stage-shield]: https://img.shields.io/badge/project%20stage-experimental-yellow.svg\n[pypi]: https://pypi.org/project/omnikinverter/\n[python-versions-shield]: https://img.shields.io/pypi/pyversions/omnikinverter\n[releases-shield]: https://img.shields.io/github/release/klaasnicolaas/python-omnikinverter.svg\n[releases]: https://github.com/klaasnicolaas/python-omnikinverter/releases\n[stars-shield]: https://img.shields.io/github/stars/klaasnicolaas/python-omnikinverter.svg\n[stars-url]: https://github.com/klaasnicolaas/python-omnikinverter/stargazers\n\n[energiewacht]: https://www.energiewacht.com/hoofdsite/home/nieuws/omnik-failliet/\n[poetry-install]: https://python-poetry.org/docs/#installation\n[poetry]: https://python-poetry.org\n[pre-commit]: https://pre-commit.com\n',
    'author': 'Klaas Schoute',
    'author_email': 'hello@student-techlife.com',
    'maintainer': 'Klaas Schoute',
    'maintainer_email': 'hello@student-techlife.com',
    'url': 'https://github.com/klaasnicolaas/python-omnikinverter',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
